use Test::More tests => 36;

BEGIN {
use_ok( 'Text::Mining::Base' );
use_ok( 'Text::Mining' );
use_ok( 'Text::Mining::Algorithm::Diff' );
use_ok( 'Text::Mining::Algorithm::AllTokens' );
use_ok( 'Text::Mining::Algorithm::Ngram' );
use_ok( 'Text::Mining::Algorithm::Porters' );
use_ok( 'Text::Mining::Algorithm::Cluster' );
use_ok( 'Text::Mining::Algorithm::LSI' );
use_ok( 'Text::Mining::Algorithm::Base' );
use_ok( 'Text::Mining::Algorithm::SVD' );
use_ok( 'Text::Mining::Protocol' );
use_ok( 'Text::Mining::Languages' );
use_ok( 'Text::Mining::Concepts::Synonym' );
use_ok( 'Text::Mining::Concepts::Mapper' );
use_ok( 'Text::Mining::Concepts::Base' );
use_ok( 'Text::Mining::Languages::Base' );
use_ok( 'Text::Mining::Languages::Dictionary' );
use_ok( 'Text::Mining::Languages::Translator' );
use_ok( 'Text::Mining::Parser::Text' );
use_ok( 'Text::Mining::Parser::Base' );
use_ok( 'Text::Mining::Parser' );
use_ok( 'Text::Mining::Representation::Primary' );
use_ok( 'Text::Mining::Representation::Tertiary' );
use_ok( 'Text::Mining::Representation::Secondary' );
use_ok( 'Text::Mining::Representation::Base' );
use_ok( 'Text::Mining::Corpus' );
use_ok( 'Text::Mining::Representation' );
use_ok( 'Text::Mining::Protocol::Index' );
use_ok( 'Text::Mining::Protocol::Base' );
use_ok( 'Text::Mining::Protocol::Algorithm' );
use_ok( 'Text::Mining::Corpus::Stats' );
use_ok( 'Text::Mining::Corpus::Annotation' );
use_ok( 'Text::Mining::Corpus::Document' );
use_ok( 'Text::Mining::Corpus::Base' );
use_ok( 'Text::Mining::Concepts' );
use_ok( 'Text::Mining::Algorithm' );
}

diag( "Found Text::Mining::Base $Text::Mining::Base::VERSION" );
diag( "Found Text::Mining $Text::Mining::VERSION" );
diag( "Found Text::Mining::Algorithm::Diff $Text::Mining::Algorithm::Diff::VERSION" );
diag( "Found Text::Mining::Algorithm::AllTokens $Text::Mining::Algorithm::AllTokens::VERSION" );
diag( "Found Text::Mining::Algorithm::Ngram $Text::Mining::Algorithm::Ngram::VERSION" );
diag( "Found Text::Mining::Algorithm::Porters $Text::Mining::Algorithm::Porters::VERSION" );
diag( "Found Text::Mining::Algorithm::Cluster $Text::Mining::Algorithm::Cluster::VERSION" );
diag( "Found Text::Mining::Algorithm::LSI $Text::Mining::Algorithm::LSI::VERSION" );
diag( "Found Text::Mining::Algorithm::Base $Text::Mining::Algorithm::Base::VERSION" );
diag( "Found Text::Mining::Algorithm::SVD $Text::Mining::Algorithm::SVD::VERSION" );
diag( "Found Text::Mining::Protocol $Text::Mining::Protocol::VERSION" );
diag( "Found Text::Mining::Languages $Text::Mining::Languages::VERSION" );
diag( "Found Text::Mining::Concepts::Synonym $Text::Mining::Concepts::Synonym::VERSION" );
diag( "Found Text::Mining::Concepts::Mapper $Text::Mining::Concepts::Mapper::VERSION" );
diag( "Found Text::Mining::Concepts::Base $Text::Mining::Concepts::Base::VERSION" );
diag( "Found Text::Mining::Languages::Base $Text::Mining::Languages::Base::VERSION" );
diag( "Found Text::Mining::Languages::Dictionary $Text::Mining::Languages::Dictionary::VERSION" );
diag( "Found Text::Mining::Languages::Translator $Text::Mining::Languages::Translator::VERSION" );
diag( "Found Text::Mining::Parser::Text $Text::Mining::Parser::Text::VERSION" );
diag( "Found Text::Mining::Parser::Base $Text::Mining::Parser::Base::VERSION" );
diag( "Found Text::Mining::Parser $Text::Mining::Parser::VERSION" );
diag( "Found Text::Mining::Representation::Primary $Text::Mining::Representation::Primary::VERSION" );
diag( "Found Text::Mining::Representation::Tertiary $Text::Mining::Representation::Tertiary::VERSION" );
diag( "Found Text::Mining::Representation::Secondary $Text::Mining::Representation::Secondary::VERSION" );
diag( "Found Text::Mining::Representation::Base $Text::Mining::Representation::Base::VERSION" );
diag( "Found Text::Mining::Corpus $Text::Mining::Corpus::VERSION" );
diag( "Found Text::Mining::Representation $Text::Mining::Representation::VERSION" );
diag( "Found Text::Mining::Protocol::Index $Text::Mining::Protocol::Index::VERSION" );
diag( "Found Text::Mining::Protocol::Base $Text::Mining::Protocol::Base::VERSION" );
diag( "Found Text::Mining::Protocol::Algorithm $Text::Mining::Protocol::Algorithm::VERSION" );
diag( "Found Text::Mining::Corpus::Stats $Text::Mining::Corpus::Stats::VERSION" );
diag( "Found Text::Mining::Corpus::Annotation $Text::Mining::Corpus::Annotation::VERSION" );
diag( "Found Text::Mining::Corpus::Document $Text::Mining::Corpus::Document::VERSION" );
diag( "Found Text::Mining::Corpus::Base $Text::Mining::Corpus::Base::VERSION" );
diag( "Found Text::Mining::Concepts $Text::Mining::Concepts::VERSION" );
diag( "Found Text::Mining::Algorithm $Text::Mining::Algorithm::VERSION" );

